@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,13 +63,9 @@ import java.util.Iterator;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
-import javax.servlet.AsyncContext;
-import javax.servlet.DispatcherType;
 import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletContext;
 import javax.servlet.ServletInputStream;
 import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13ServletInputStream;
 import com.openexchange.ajp13.exception.AJPv13Exception;
@@ -153,7 +149,7 @@ public class ServletRequestWrapper implements ServletRequest {
         attributes = new HashMap<String, Object>(32);
         parameters = new HashKeyMap<String[]>(max > 0 ? max : 64).setGenerator(hashKeyGenerator);
         headers = new HashMap<String, String[]>(16);
-        setHeaderInternal(CONTENT_LENGTH, String.valueOf(-1), false);
+        setHeaderInternal(CONTENT_LENGTH, Integer.toString(-1), false);
     }
 
     /**
@@ -163,7 +159,7 @@ public class ServletRequestWrapper implements ServletRequest {
      * @throws AJPv13Exception If setting <code>Content-Length</code> header fails
      */
     public void setContentLength(final int contentLength) throws AJPv13Exception {
-        setHeaderInternal(CONTENT_LENGTH, String.valueOf(contentLength), false);
+        setHeaderInternal(CONTENT_LENGTH, Integer.toString(contentLength), false);
     }
 
     /**
@@ -295,7 +291,7 @@ public class ServletRequestWrapper implements ServletRequest {
      * @param name The header name
      * @return The header values as an {@link Enumeration}
      */
-    public Enumeration<String> getHeaders(final String name) {
+    public Enumeration<?> getHeaders(final String name) {
         return makeEnumeration(headers.get(name.toLowerCase(Locale.ENGLISH)));
     }
 
@@ -304,7 +300,7 @@ public class ServletRequestWrapper implements ServletRequest {
      *
      * @return The header names as an {@link Enumeration}
      */
-    public Enumeration<String> getHeaderNames() {
+    public Enumeration<?> getHeaderNames() {
         return makeEnumeration(headers.keySet().iterator());
     }
 
@@ -330,12 +326,12 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<String> getParameterNames() {
+    public Enumeration<?> getParameterNames() {
         return makeEnumeration(parameters.keySet().iterator());
     }
 
     @Override
-    public Map<String, String[]> getParameterMap() {
+    public Map<?, ?> getParameterMap() {
         return Collections.unmodifiableMap(parameters);
     }
 
@@ -355,7 +351,7 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<String> getAttributeNames() {
+    public Enumeration<?> getAttributeNames() {
         return makeEnumeration(attributes.keySet().iterator());
     }
 
@@ -416,7 +412,7 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<Locale> getLocales() {
+    public Enumeration<?> getLocales() {
         return null;
     }
 
@@ -521,7 +517,7 @@ public class ServletRequestWrapper implements ServletRequest {
              * Determine scheme from protocol (in the form protocol/majorVersion.minorVersion) and isSecure information
              */
             scheme =
-                new com.openexchange.java.StringAllocator(protocol.substring(0, protocol.indexOf('/')).toLowerCase(Locale.ENGLISH)).append(secure ? "s" : "").toString();
+                new StringBuilder(protocol.substring(0, protocol.indexOf('/')).toLowerCase(Locale.ENGLISH)).append(secure ? "s" : "").toString();
         }
         return scheme;
     }
@@ -666,39 +662,4 @@ public class ServletRequestWrapper implements ServletRequest {
         return clone;
     }
 
-    @Override
-    public ServletContext getServletContext() {
-        return null;
-    }
-
-    @Override
-    public AsyncContext startAsync() throws IllegalStateException {
-        return null;
-    }
-
-    @Override
-    public AsyncContext startAsync(final ServletRequest servletRequest, final ServletResponse servletResponse) throws IllegalStateException {
-        return null;
-    }
-
-    @Override
-    public boolean isAsyncStarted() {
-        return false;
-    }
-
-    @Override
-    public boolean isAsyncSupported() {
-        return false;
-    }
-
-    @Override
-    public AsyncContext getAsyncContext() {
-        return null;
-    }
-
-    @Override
-    public DispatcherType getDispatcherType() {
-        return null;
-    }
-
 }
