@@ -54,8 +54,6 @@ import gnu.trove.map.hash.TIntObjectHashMap;
 import java.io.IOException;
 import java.lang.reflect.Array;
 import java.text.DateFormat;
-import java.util.Arrays;
-import java.util.Collection;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.Iterator;
@@ -69,13 +67,13 @@ import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.SessionServlet;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13RequestHandler;
-import com.openexchange.ajp13.AJPv13ServiceRegistry;
+import com.openexchange.ajp13.Services;
 import com.openexchange.ajp13.servlet.ServletResponseWrapper;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.java.Charsets;
-import com.openexchange.server.impl.Version;
 import com.openexchange.session.Session;
+import com.openexchange.version.Version;
 
 /**
  * HttpServletResponseWrapper
@@ -165,7 +163,7 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         cookies = new LinkedHashSet<Cookie>();
         status = HttpServletResponse.SC_OK;
         this.request = request;
-        final ConfigurationService cs = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
+        final ConfigurationService cs = Services.getService(ConfigurationService.class);
         httpOnly = (null != cs && cs.getBoolProperty(ServerConfig.Property.COOKIE_HTTP_ONLY.getPropertyName(), true));
     }
 
@@ -261,7 +259,7 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         }
         final StringBuilder sb = new StringBuilder(path);
         if (httpSessionId != null && sb.length() > 0) {
-            sb.append("/");
+            sb.append('/');
             sb.append(AJPv13RequestHandler.JSESSIONID_URI);
             sb.append(httpSessionId);
         }
@@ -291,7 +289,7 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
 
     @Override
     public void addIntHeader(final String name, final int i) {
-        addHeader(name, String.valueOf(i));
+        addHeader(name, Integer.toString(i));
     }
 
     @Override
@@ -353,11 +351,17 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         if (cookie.getVersion() > 0) {
             composer.append(COOKIE_PARAMS[1]).append(cookie.getVersion());
         }
-        if (cookie.getPath() != null) {
-            composer.append(COOKIE_PARAMS[2]).append(cookie.getPath());
+        {
+            final String path = cookie.getPath();
+            if (!isEmpty(path)) {
+                composer.append(COOKIE_PARAMS[2]).append(path);
+            }
         }
-        if (cookie.getDomain() != null) {
-            composer.append(COOKIE_PARAMS[3]).append(cookie.getDomain());
+        {
+            final String domain = cookie.getDomain();
+            if (!isEmpty(domain)) {
+                composer.append(COOKIE_PARAMS[3]).append(domain);
+            }
         }
         if (cookie.getSecure()) {
             composer.append(COOKIE_PARAMS[4]);
@@ -374,6 +378,18 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         return composer.toString();
     }
 
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
+    }
+
     @Override
     public void addHeader(final String name, final String value) {
         if (!headers.containsKey(name)) {
@@ -387,7 +403,6 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         headers.put(name, val);
     }
 
-    @Override
     public int getStatus() {
         return status;
     }
@@ -419,7 +434,7 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
 
     @Override
     public void setIntHeader(final String name, final int i) {
-        setHeader(name, String.valueOf(i));
+        setHeader(name, Integer.toString(i));
     }
 
     @Override
@@ -438,21 +453,18 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
         return headers.size();
     }
 
-    @Override
-    public Collection<String> getHeaderNames() {
-        return headers.keySet();
+    public final Iterator<String> getHeaderNames() {
+        return headers.keySet().iterator();
     }
 
     public final Set<Map.Entry<String, String[]>> getHeaderEntrySet() {
         return headers.entrySet();
     }
 
-    @Override
-    public Collection<String> getHeaders(final String name) {
-        return Arrays.asList(headers.get(name));
+    public Enumeration<?> getHeaders(final String name) {
+        return makeEnumeration(headers.get(name));
     }
 
-    @Override
     public final String getHeader(final String name) {
         if (!containsHeader(name)) {
             return null;
@@ -482,9 +494,8 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
      * @param status The status to set
      * @param statusMsg The (optional) status message or <code>null</code>
      * @return The error message in bytes
-     * @throws IOException If an I/O error occurs
      */
-    public final byte[] composeAndSetError(final int status, final String statusMsg) throws IOException {
+    public final byte[] composeAndSetError(final int status, final String statusMsg) {
         this.status = status;
         this.statusMsg = statusMsg == null ? STATUS_MSGS.get(status) : statusMsg;
         String desc = STATUS_DESC.containsKey(this.status) ? STATUS_DESC.get(this.status) : ERR_DESC_NOT_AVAILABLE;
@@ -492,13 +503,13 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
             desc = String.format(desc, request.getServletPath());
         }
         String errorMsgStr = ERROR_PAGE_TEMPL;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", String.valueOf(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
+        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", Integer.toString(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
             "#STATUS_DESC#",
             desc);
         synchronized (HEADER_DATE_FORMAT) {
             errorMsgStr = errorMsgStr.replaceFirst("#DATE#", HEADER_DATE_FORMAT.format(new Date(System.currentTimeMillis())));
         }
-        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getVersionString());
+        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getInstance().getVersionString());
         setContentType(new StringBuilder("text/html; charset=").append(getCharacterEncoding()).toString());
         final byte[] errormessage = errorMsgStr.getBytes(Charsets.forName(getCharacterEncoding()));
         setContentLength(errormessage.length);
@@ -516,21 +527,20 @@ public class HttpServletResponseWrapper extends ServletResponseWrapper implement
      * Gets the default error page.
      *
      * @return The default error page
-     * @throws IOException If an I/O error occurs
      */
-    public byte[] getErrorMessage() throws IOException {
+    public byte[] getErrorMessage() {
         String desc = STATUS_DESC.containsKey(this.status) ? STATUS_DESC.get(this.status) : ERR_DESC_NOT_AVAILABLE;
         if (HttpServletResponse.SC_NOT_FOUND == status) {
             desc = String.format(desc, request.getServletPath());
         }
         String errorMsgStr = ERROR_PAGE_TEMPL;
-        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", String.valueOf(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
+        errorMsgStr = errorMsgStr.replaceAll("#STATUS_CODE#", Integer.toString(this.status)).replaceAll("#STATUS_MSG#", this.statusMsg).replaceFirst(
             "#STATUS_DESC#",
             desc);
         synchronized (HEADER_DATE_FORMAT) {
             errorMsgStr = errorMsgStr.replaceFirst("#DATE#", HEADER_DATE_FORMAT.format(new Date(System.currentTimeMillis())));
         }
-        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getVersionString());
+        errorMsgStr = errorMsgStr.replaceFirst("#VERSION#", Version.getInstance().getVersionString());
         String encoding = getCharacterEncoding();
         if (null == encoding) {
             encoding = "UTF-8";
