@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -157,7 +157,7 @@ public final class AJPv13Utility {
             return "";
         }
         final String space = "    ";
-        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
+        final StringBuilder sb = new StringBuilder(1024);
         int c = 0;
         int l = 0;
         for (final byte b : bytes) {
@@ -197,7 +197,7 @@ public final class AJPv13Utility {
             return "";
         }
         final String space = "    ";
-        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
+        final StringBuilder sb = new StringBuilder(1024);
         sb.append("0000").append(space).append(Integer.toHexString(magic1).toUpperCase()).append(' ').append(
             Integer.toHexString(magic2).toUpperCase());
         int c = 2;
@@ -234,7 +234,7 @@ public final class AJPv13Utility {
      */
     public static String dumpByte(final byte b) {
         final String s = Integer.toHexString(b & 0xff).toUpperCase();
-        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(4).append("0x");
+        final StringBuilder sb = new StringBuilder(4).append("0x");
         if (s.length() == 1) {
             sb.append('0');
         }
